==> javie-0.3.4-src.tar.gz: javie-0.3.4-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/Layer.java <==
/*
 * Copyright (c) 2009 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core;

import ch.kuramo.javie.api.Time;

public interface Layer extends Expressionee {

	String getId();

	Layer getParent();

	void setParent(Layer parent);

	String getName();

	void setName(String name);

	boolean isShy();

	void setShy(boolean shy);


	Time getStartTime();

	void setStartTime(Time startTime);

	Time getInPoint();

	void setInPoint(Time inPoint);

	Time getOutPoint();

	void setOutPoint(Time outPoint);

	double getRate();

	void setRate(double rate);


	void afterDecode(Project p, LayerComposition c) throws ProjectDecodeException;

	void prepareExpression(ExpressionScope scope);

}

==> javie-0.5.9-src.tar.gz: javie-0.5.9-src/ch.kuramo.javie.core/src/main/java/ch/kuramo/javie/core/Layer.java <==
/*
 * Copyright (c) 2009,2010 Yoshikazu Kuramochi
 * All rights reserved.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package ch.kuramo.javie.core;

import ch.kuramo.javie.api.Time;

public interface Layer extends Expressionee {

	String getId();

	String getParentId();

	void setParentId(String parentId);

	String getName();

	void setName(String name);

	boolean isShy();

	void setShy(boolean shy);


	Time getStartTime();

	void setStartTime(Time startTime);

	Time getInPoint();

	void setInPoint(Time inPoint);

	Time getOutPoint();

	void setOutPoint(Time outPoint);

	double getRate();

	void setRate(double rate);


	void afterDecode(Project p, LayerComposition c) throws ProjectDecodeException;

	void prepareExpression(ExpressionScope scope);

}
